==> lordsawar_0.2.0.orig.tar.gz: lordsawar-0.2.0/src/editor/tileset-smallmap-building-colors-dialog.h <==
//  Copyright (C) 2010 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#ifndef TILESET_SMALLMAP_BUILDING_COLORS_DIALOG_H
#define TILESET_SMALLMAP_BUILDING_COLORS_DIALOG_H

#include <memory>
#include <sigc++/trackable.h>
#include <gtkmm.h>
class Tileset;

class TilesetSmallmapBuildingColorsDialog: public sigc::trackable
{
 public:
    TilesetSmallmapBuildingColorsDialog(Tileset *tileset);
    ~TilesetSmallmapBuildingColorsDialog();

    void set_parent_window(Gtk::Window &parent);

    int run();

    void hide();
    
 private:
    Tileset *d_tileset;
    Gtk::Dialog *dialog;
    Gtk::ColorButton *road_colorbutton;
    Gtk::ColorButton *ruin_colorbutton;
    Gtk::ColorButton *temple_colorbutton;

    void on_road_color_chosen();
    void on_ruin_color_chosen();
    void on_temple_color_chosen();
};

#endif

==> lordsawar-0.3.3-pre2.tar.gz: lordsawar-0.3.3-pre2/src/editor/tileset-smallmap-building-colors-dialog.h <==
//  Copyright (C) 2010, 2014, 2020, 2021 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#pragma once
#ifndef TILESET_SMALLMAP_BUILDING_COLORS_DIALOG_H
#define TILESET_SMALLMAP_BUILDING_COLORS_DIALOG_H

#include <gtkmm.h>
#include "lw-editor-dialog.h"
#include "undo-mgr.h"
class Tileset;

class TilesetSmallmapBuildingColorsDialog: public LwEditorDialog
{
 public:
    TilesetSmallmapBuildingColorsDialog(Gtk::Window &parent, Tileset *tileset);
    ~TilesetSmallmapBuildingColorsDialog();

    bool get_changed () {return d_changed;}
 private:
    UndoMgr *umgr;
    bool d_changed;
    Tileset *d_tileset;
    Gtk::ColorButton *road_colorbutton;
    Gtk::ColorButton *ruin_colorbutton;
    Gtk::ColorButton *temple_colorbutton;
    Gtk::Button *undo_button;
    Gtk::Button *redo_button;

    void on_road_color_chosen();
    void on_ruin_color_chosen();
    void on_temple_color_chosen();

    void on_undo_activated ();
    void on_redo_activated ();
    void update ();
    void connect_signals ();
    void disconnect_signals ();
    std::list<sigc::connection> connections;
    UndoAction *executeAction (UndoAction *action);
};

#endif
